@@ -13,7 +13,6 @@ class Parse:
     """
 
     def _load(self):
-
         if not self.input_file.exists():
             raise FileNotFoundError
         else:
@@ -27,26 +26,8 @@ class Parse:
                 raise ValueError("Unknown format (must be .json .yml .yaml)")
 
     def _verify(self):
-        self.verified = set()
-        print(f"... verifying calls")
-        if not self.calls:
-            self.verified.add(False)
-        elif not "type" in self.calls.keys():
-            self.verified.add(False)
-            raise ValueError('No "type" key in {}'.format(self.input_file))
-        elif not self.calls["type"] in self.call_types:
-            self.verified.add(False)
-            raise ValueError(
-                'Unknown call type "{}"\n(must be in {})'.format(
-                    self.calls["type"], self.call_types
-                )
-            )
-        else:
-            for k, v in self.calls.items():
-                if k != "type":
-                    if not "call" in v.keys():
-                        self.verified.add(False)
-                        raise ValueError('No "call" key in "{}"'.format(k))
+        # Disabled
+        pass
 
     def _save(self):
         if not self.output_file:
@@ -83,8 +64,6 @@ class Parse:
         else:
             self.output_file = None
 
-        self.call_types = [k for k in sgex.call_types.keys()]
-
         # Get input
         if isinstance(input, str):
             self.input_file = pathlib.Path(input)
@@ -95,7 +74,7 @@ class Parse:
             raise TypeError("Valid inputs: filepath (str) or dict")
 
         # Execute
-        self._verify()
+        # self._verify()
 
         if not self.output_file:
             self._return()
